@@ -3,46 +3,34 @@
 
 # should new trap ID be numeric , character or factor???
 # 2015-01-31 join() bug fix could fail with exclusivedetector types
+# 2015-04-05 previous bug fix failed...
+
+# 2015-04-13
 
 join <- function (object, remove.dupl.sites = TRUE, tol = 0.001) {
+
+    ####################################################################
     onesession <- function (sess) {
-        ## previous is cumulative number of preceding occasions
         CH <- object[[sess]]
-        previous <- before[sess]
         newID <- animalID(CH)
-        occ <- occasion(CH)
-        newocc <- occ + previous
+        newocc <- occasion(CH) + before[sess]
         newtrap <- trap(CH)
         df <- data.frame(newID = newID, newocc = newocc, newtrap = newtrap,
-                         alive = alive(CH), sess = rep(sess, length(occ)),
+                         alive = alive(CH), sess = rep(sess, length(newID)),
                          stringsAsFactors = FALSE)
         if (!is.null(xy(CH))) {
             df$x <- xy(CH)$x
             df$y <- xy(CH)$y
         }
-        if (!is.null(signal(CH)))
+        if (!is.null(signal(CH)))  {
             df$signal <- signal(CH)
+        }        
         df
     }
-    #    if (!ms(object) | !inherits(object, 'capthist'))   
-    if (!ms(object) | any(sapply(object, class) != 'capthist'))
-        stop("requires multi-session capthist object or list of single-session capthist")
+    ####################################################################
     
-    outputdetector <- detector(traps(object)[[1]])
-    nsession <- length(object)
-
-    nocc <- sapply(object, ncol)
-    names(nocc) <- NULL
-    before <- c(0, cumsum(nocc)[-nsession])
-    df <- vector(mode= 'list', length = nsession)
-    for (sess in 1:nsession) {
-        df[[sess]] <- onesession (sess)
-    }
-    df <- do.call(rbind, df)
-
-    n <- length(unique(df$newID))
-    condition.usage <- function (trp, i, nocc) {
-        us <- matrix(0, nrow=nrow(trp), ncol=sum(nocc))
+    condition.usage <- function (trp, i) {
+        us <- matrix(0, nrow=nrow(trp), ncol=nnewocc)
         s1 <- c(1, cumsum(nocc)+1)[i]
         s2 <- cumsum(nocc)[i]
         if (is.null(usage(trp)))
@@ -52,18 +40,42 @@ join <- function (object, remove.dupl.sites = TRUE, tol = 0.001) {
         usage(trp) <- us
         trp
     }
+    ####################################################################
+    
+    if (!ms(object) | any(sapply(object, class) != 'capthist'))
+        stop("requires multi-session capthist object or list of single-session capthist")
+    
+    outputdetector <- detector(traps(object)[[1]])
+    nsession <- length(object)
+    nocc <- sapply(object, ncol)
+    names(nocc) <- NULL
+    nnewocc <- sum(nocc)
+    ## cumulative number of preceding occasions
+    before <- c(0, cumsum(nocc)[-nsession])
+    df <- lapply(1:nsession, onesession)
+    df <- do.call(rbind, df)
+    n <- length(unique(df$newID))
 
     ## resolve traps
-    temptrp <- traps(object)
-    for (i in 1:length(temptrp))
-        temptrp[[i]] <- condition.usage(temptrp[[i]], i, nocc)
-
-    alltemptrp <- do.call(rbind, c(temptrp, renumber = FALSE))
-    newtraps <- alltemptrp
-    df$newtrap <- paste(df$newtrap,df$sess, sep=".")
-
+    ## first check whether all the same (except usage)
+    temptrp <- lapply(traps(object), function(x) {usage(x) <- NULL; x})
+    sametrp <- all(sapply(temptrp[-1], identical, temptrp[[1]]))
+    if (sametrp & remove.dupl.sites) {
+        newtraps <- temptrp[[1]]
+        class(newtraps) <- c("traps", "data.frame")
+        if (length(usage(traps(object))) > 0)
+            usage(newtraps) <- do.call(cbind, usage(traps(object)))
+        ## df$newtrap unchanged
+    }
+    else {    
+        temptrp <- mapply(condition.usage, traps(object), 1:nsession)    
+        newtraps <- do.call(rbind, c(temptrp, renumber = FALSE))        
+        class(newtraps) <- c("traps", "data.frame")
+        df$newtrap <- paste(df$newtrap,df$sess, sep=".")
+    }
+    
     # ensure retain all occasions
-    df$newocc <- factor(df$newocc, levels = 1:sum(nocc))
+    df$newocc <- factor(df$newocc, levels = 1:nnewocc)
 
     if (outputdetector %in% .localstuff$exclusivedetectors) {
         alivesign <- df$alive*2 - 1
@@ -72,7 +84,9 @@ join <- function (object, remove.dupl.sites = TRUE, tol = 0.001) {
         
         ## bug fix 2015-01-31
         ## tempnew[cbind(df$newID, df$newocc)] <- as.numeric(df$newtrap) * alivesign
-        trapindex <- match(df$newtrap, unique(df$newtrap))        
+        ## bug fix 2015-04-05
+        ## trapindex <- match(df$newtrap, unique(df$newtrap))    
+        trapindex <- match(df$newtrap, rownames(newtraps))
         tempnew[cbind(df$newID, df$newocc)] <- trapindex * alivesign
     }
     else {
@@ -93,17 +107,19 @@ join <- function (object, remove.dupl.sites = TRUE, tol = 0.001) {
 
     if (!is.null(df$signal))
         signal(tempnew) <- df[neworder,'signal']
-
+    
     if (!is.null(covariates(object))) {
         tempcov <- do.call(rbind, covariates(object))
-        IDcov <- unlist(lapply(object,rownames))
-        ## use first match
-        tempcov <- tempcov[match(rownames(tempnew), IDcov),,drop = FALSE]
-        rownames(tempcov) <- rownames(tempnew)
-        covariates(tempnew) <- tempcov
+        if (!is.null(tempcov)) {
+            IDcov <- unlist(lapply(object,rownames))
+            ## use first match
+            tempcov <- tempcov[match(rownames(tempnew), IDcov),,drop = FALSE]
+            rownames(tempcov) <- rownames(tempnew)
+            covariates(tempnew) <- tempcov
+        }
     }
 
-    if (remove.dupl.sites)
+    if (remove.dupl.sites & !sametrp)
         tempnew <- reduce(tempnew, span=tol, dropunused = FALSE, verify = FALSE)
     attr(tempnew, 'interval') <- unlist(sapply(nocc, function(x) c(1,rep(0,x-1))))[-1]
 
